@@ -14,6 +14,7 @@
 #include <QDir>
 #include <QFile>
 #include <QHash>
+#include <QPointer>
 #include <QSet>
 #include <QTextStream>
 #include <QThreadPool>
@@ -106,6 +107,7 @@ public:
     QFile mFile;
     char mBuffer[PROCESS_BUFFER_SIZE + 1]; // used as a buffer to read data into
     DIR *mProcDir;
+    QPointer<ReadProcSmapsRunnable> smapsRunnable;
 };
 
 ProcessesLocal::Private::~Private()
@@ -574,14 +576,14 @@ bool ProcessesLocal::updateProcessInfo(long pid, Process *process)
     bool success = true;
     const QString dir = QLatin1String("/proc/") + QString::number(pid) + QLatin1Char('/');
 
-    if (mUpdateFlags.testFlag(Processes::Smaps)) {
-        auto runnable = new ReadProcSmapsRunnable{dir};
+    if (mUpdateFlags.testFlag(Processes::Smaps) && !d->smapsRunnable) {
+        d->smapsRunnable = new ReadProcSmapsRunnable{dir};
 
-        connect(runnable, &ReadProcSmapsRunnable::finished, this, [this, pid](qulonglong pss) {
+        connect(d->smapsRunnable, &ReadProcSmapsRunnable::finished, this, [this, pid](qulonglong pss) {
             Q_EMIT processUpdated(pid, {{Process::VmPSS, pss}});
         });
 
-        QThreadPool::globalInstance()->start(runnable);
+        QThreadPool::globalInstance()->start(d->smapsRunnable);
     }
 
     if (!d->readProcStat(dir, process)) {
